import { Plugin, GraphileBuildOptions, SchemaListener, Build, Context, SchemaBuilder, Inflection, GraphileResolverContext } from "graphile-build";
import { inflections, Inflector, formatSQLForDebugging } from "graphile-build-pg";
import { Pool, PoolClient } from "pg";
import { SignOptions, Secret } from "jsonwebtoken";
export { Plugin, Build, Context, SchemaBuilder, SchemaListener, Inflection, GraphileBuildOptions, GraphileBuildOptions as Options, formatSQLForDebugging, GraphileResolverContext, };
export declare type mixed = {} | string | number | boolean | undefined | null;
export interface PostGraphileCoreOptions {
    dynamicJson?: boolean;
    classicIds?: boolean;
    disableDefaultMutations?: boolean;
    nodeIdFieldName?: string;
    /**
     * Additional Options to pass through into the graphile schema building
     * system (received via the second argument of a plugin).
     */
    graphileBuildOptions?: Partial<GraphileBuildOptions>;
    /**
     * @deprecated Use graphileBuildOptions instead
     */
    graphqlBuildOptions?: Partial<GraphileBuildOptions>;
    replaceAllPlugins?: Array<Plugin>;
    appendPlugins?: Array<Plugin>;
    /**
     * @deprecated Use `appendPlugins` with dependencies instead.
     */
    prependPlugins?: Array<Plugin>;
    skipPlugins?: Array<Plugin>;
    jwtPgTypeIdentifier?: string;
    jwtSecret?: Secret;
    jwtSignOptions?: SignOptions;
    /**
     * @deprecated UNSUPPORTED! Use an inflector plugin instead.
     */
    inflector?: Inflector;
    /**
     * @deprecated Use smart comments/tags instead
     */
    pgColumnFilter?: <TContext extends Context>(attr: mixed, build: Build, context: TContext) => boolean;
    /**
     * @deprecated Use '\@primaryKey' smart comment instead
     */
    viewUniqueKey?: string;
    enableTags?: boolean;
    readCache?: string | object;
    writeCache?: string;
    setWriteCacheCallback?: (fn: () => Promise<void>) => void;
    legacyRelations?: "only" | "deprecated" | "omit";
    setofFunctionsContainNulls?: boolean;
    legacyJsonUuid?: boolean;
    simpleCollections?: "only" | "both" | "omit";
    includeExtensionResources?: boolean;
    ignoreRBAC?: boolean;
    legacyFunctionsOnly?: boolean;
    ignoreIndexes?: boolean;
    hideIndexWarnings?: boolean;
    subscriptions?: boolean;
    live?: boolean;
    ownerConnectionString?: string;
}
export { inflections };
export declare const postGraphileBaseOverrides: {
    enumName(value: string): string;
};
export declare const postGraphileClassicIdsOverrides: {
    column(name: string, _table: string, _schema?: string | undefined): string;
};
export declare const postGraphileInflection: inflections.Inflector;
export declare const postGraphileClassicIdsInflection: inflections.Inflector;
export declare const PostGraphileInflectionPlugin: Plugin;
export declare const PostGraphileClassicIdsInflectionPlugin: Plugin;
export declare const getPostGraphileBuilder: (pgConfig: string | Pool | PoolClient, schemas: string | string[], options?: PostGraphileCoreOptions) => Promise<SchemaBuilder>;
export declare const createPostGraphileSchema: (pgConfig: string | Pool | PoolClient, schemas: string | string[], options?: PostGraphileCoreOptions) => Promise<import("graphql").GraphQLSchema>;
export declare const watchPostGraphileSchema: (pgConfig: string | Pool | PoolClient, schemas: string | string[], options: PostGraphileCoreOptions | undefined, onNewSchema: SchemaListener) => Promise<() => Promise<void>>;
export declare const postGraphQLBaseOverrides: {
    enumName(value: string): string;
};
export declare const postGraphQLClassicIdsOverrides: {
    column(name: string, _table: string, _schema?: string | undefined): string;
};
export declare const postGraphQLInflection: inflections.Inflector;
export declare const postGraphQLClassicIdsInflection: inflections.Inflector;
export declare const createPostGraphQLSchema: (pgConfig: string | Pool | PoolClient, schemas: string | string[], options?: PostGraphileCoreOptions) => Promise<import("graphql").GraphQLSchema>;
export declare const watchPostGraphQLSchema: (pgConfig: string | Pool | PoolClient, schemas: string | string[], options: PostGraphileCoreOptions | undefined, onNewSchema: SchemaListener) => Promise<() => Promise<void>>;
//# sourceMappingURL=index.d.ts.map